@@ -18,6 +18,7 @@ import (
 	"os"
 	"os/exec"
 	"path/filepath"
+	"reflect"
 	"regexp"
 	"runtime"
 	"runtime/debug"
@@ -33,16 +34,16 @@ var (
 	regenerate   = flag.Bool("regenerate", false, "regenerate files")
 	buildRelease = flag.Bool("buildRelease", false, "build release binaries")
 
-	protobufVersion = "27.0"
+	protobufVersion = "27.0-rc1"
 
 	golangVersions = func() []string {
-		// Version policy: oldest supported version of Go, plus the version before that.
-		// This matches the version policy of the Google Cloud Client Libraries:
-		// https://cloud.google.com/go/getting-started/supported-go-versions
+		// Version policy: same version as is in the x/ repos' go.mod.
 		return []string{
-			"1.20.14",
-			"1.21.10",
-			"1.22.3",
+			"1.17.13",
+			"1.18.10",
+			"1.19.13",
+			"1.20.12",
+			"1.21.5",
 		}
 	}()
 	golangLatest = golangVersions[len(golangVersions)-1]
@@ -562,9 +563,15 @@ func race() bool {
 	if !ok {
 		return false
 	}
-	for _, setting := range bi.Settings {
-		if setting.Key == "-race" {
-			return setting.Value == "true"
+	// Use reflect because the debug.BuildInfo.Settings field
+	// isn't available in Go 1.17.
+	s := reflect.ValueOf(bi).Elem().FieldByName("Settings")
+	if !s.IsValid() {
+		return false
+	}
+	for i := 0; i < s.Len(); i++ {
+		if s.Index(i).FieldByName("Key").String() == "-race" {
+			return s.Index(i).FieldByName("Value").String() == "true"
 		}
 	}
 	return false
